# Support

- If you found a bug, or wish to propose a new feature, please follow [this guide][issue-guide]
- If you just want to ask a question, feel free to do so on the [project's discussion board][github-discussions], or get
  in touch through our [discord server].
- In case you have a security concern, or some other problem that requires private resolution, please follow our
  [security policy] to disclose the issue appropriately.

[issue-guide]: ../contributing/issue-guide.md
[github-discussions]: https://github.com/py-mine/mcproto/discussions
[discord server]: https://discord.gg/C2wX7zduxC
[security policy]: ../contributing/security-policy.md
